@@ -74,10 +74,8 @@ class Move(ABC):
         move = "{}{}{}".format(position, new_letter, new_number)
         return cls(move)
 
-    # TODO Should this be moved to boardmove?
-    # Or maybe some generator that implements this, returns the actual squres.
-    def squares_between(self):
-        """Return the squares between the origin and destination.
+    def square_selectors_between(self):
+        """Return selectors of squares between the origin and destination.
 
         Returns:
             list(String): A list of selectors of squares.
